@@ -15,6 +15,7 @@ from sr_models.base import (
     SavedLocation,
     SavedLocationCreationRequest,
 )
+from sr_models.user import UserProfile
 from sr_models.lineage import LineageReport
 from sr_models.search import Search, SearchRequest, SearchResponse
 
@@ -185,6 +186,20 @@ class SpacerakeSDK:
 
         return False
 
+
+    async def self_profile(self) -> UserProfile:
+        '''
+        Gets the current user's profile.
+
+        :return: User profile 
+        :rtype: UserProfile
+        '''
+
+        return await self.__abstract_get(
+            '/api/v0/special/auth/me',
+            List[Order]
+        )
+
     
     # --- ORDERS ---
 
